pub enum ResolvedLink {
Hyperlink {
href: String,
},
Slashlink {
link: Slashlink,
href: String,
},
}Expand description
This enum represents the resolved value that may be returned by a Resolver and is provided to a Transcluder
Variants